%global with_debug 1

%if 0%{?with_debug}
%global _find_debuginfo_dwz_opts %{nil}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package %{nil}
%endif

# Golang minor version
%if 0%{?rhel} && ! 0%{?fedora}
%define gobuild(o:) go build -buildmode pie -compiler gc -tags="rpm_crashtraceback libtrust_openssl ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -compressdwarf=false -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%else
%define gobuild(o:) go build -buildmode pie -compiler gc -tags="rpm_crashtraceback ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%endif

%global provider github
%global provider_tld com
%global project cri-o
%global repo cri-o
# https://github.com/cri-o/cri-o
%global import_path %{provider}.%{provider_tld}/%{project}/%{repo}
%global commit0 1cc7a649eee19d3717c2157821f3a3b9144f33ba
%global shortcommit0 %(c=%{commit0}; echo ${c:0:7})
%global git0 https://%{import_path}

%global service_name crio

Name: %{repo}
Version: 1.27.2
Release: 7.rhaos4.14.git%{shortcommit0}%{?dist}
Summary: Kubernetes Container Runtime Interface for OCI-based containers
License: ASL 2.0
URL: %{git0}
Source0: %{git0}/archive/%{commit0}/%{name}-%{shortcommit0}.tar.gz
Source1: unshare.json
Source2: seccomp.json
Source3: crio-seccomp.conf
BuildRequires: golang
BuildRequires: git
BuildRequires: glib2-devel
BuildRequires: glibc-static
BuildRequires: go-md2man
BuildRequires: gpgme-devel
BuildRequires: libassuan-devel
BuildRequires: libseccomp-devel
BuildRequires: pkgconfig(systemd)
Requires: shadow-utils
Requires(pre): container-selinux
Requires: skopeo-containers >= 1:0.1.40-1
Requires: runc >= 1.0.0-61.rc8
Obsoletes: ocid <= 0.3
Provides: ocid = %{version}-%{release}
Provides: %{service_name} = %{version}-%{release}
Requires: containernetworking-plugins >= 0.8.2-3
Requires: conmon >= 2.0.2-2

%description
%{summary}

%prep
%autosetup -Sgit -n %{name}-%{commit0}
sed -i 's/\.gopathok //' Makefile
sed -i 's/%{version}/%{version}-%{release}/' internal/version/version.go
sed -i 's/\/local//' contrib/systemd/%{service_name}.service
sed -i 's/\/local//' contrib/systemd/%{service_name}-wipe.service

%build
mkdir _output
pushd _output
mkdir -p src/%{provider}.%{provider_tld}/{%{project},opencontainers}
ln -s $(dirs +1 -l) src/%{import_path}
popd

ln -s vendor src
export GOPATH=$(pwd)/_output:$(pwd)
export BUILDTAGS="selinux seccomp exclude_graphdriver_devicemapper exclude_graphdriver_btrfs containers_image_ostree_stub"
export GO111MODULE=off
# https://bugzilla.redhat.com/show_bug.cgi?id=1825623
export VERSION=%{version}
# build crio
%gobuild -o bin/%{service_name} %{import_path}/cmd/%{service_name}

# build crio-status
%gobuild -o bin/crio-status %{import_path}/cmd/crio-status

# build pinns and docs
%{__make} bin/pinns
%if 0%{?rhel} <= 7 && ! 0%{?fedora}
GO_MD2MAN=go-md2man GO="scl enable go-toolset-1.13 -- go" %{__make} docs
%else
GO_MD2MAN=go-md2man %{__make} docs
%endif

%install
./bin/%{service_name} \
      --selinux \
      --cgroup-manager "systemd" \
      --cni-plugin-dir "%{_libexecdir}/cni" \
      --metrics-port 9537 \
      --enable-metrics \
      --runtimes crun::/run/crun:oci \
      config > %{service_name}.conf

# install conf files
install -dp %{buildroot}%{_sysconfdir}/cni/net.d
install -p -m 644 contrib/cni/10-crio-bridge.conflist %{buildroot}%{_sysconfdir}/cni/net.d/100-crio-bridge.conflist
install -p -m 644 contrib/cni/99-loopback.conflist %{buildroot}%{_sysconfdir}/cni/net.d/200-loopback.conflist
make PREFIX=%{buildroot}%{_prefix} DESTDIR=%{buildroot} \
            install.bin-nobuild \
            install.completions \
            install.config-nobuild \
            install.man-nobuild \
            install.systemd

# install seccomp.json
install -p -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/%{service_name}/seccomp.json
install -dp %{buildroot}%{_sharedstatedir}/containers
install -dp %{buildroot}%{_libexecdir}/%{service_name}
install -dp %{buildroot}%{_sharedstatedir}/cni/bin
install -dp %{buildroot}%{_sysconfdir}/kubernetes/cni/net.d
install -dp %{buildroot}%{_datadir}/containers/oci/hooks.d
install -dp %{buildroot}/opt/cni/bin
install -p -m 644 %{SOURCE1} %{buildroot}/%{_libexecdir}/%{service_name}/unshare.json

# install crio-seccomp.conf
install -dp %{buildroot}/%{_tmpfilesdir}
install -m 644 %{SOURCE3} %{buildroot}/%{_tmpfilesdir}

# write service file to enable ID ranges
cat > %{buildroot}%{_unitdir}/%{service_name}-subid.service <<EOF
[Unit]
Description=Generation of shadow ID ranges for CRI-O
Before=crio.service

[Service]
Type=oneshot
ExecStart=%{_libexecdir}/%{service_name}/%{service_name}-subid.sh

[Install]
WantedBy=multi-user.target %{service_name}.service
EOF

# Write the script the aforementioned service file will call to enable ID ranges
cat > %{service_name}-subid.sh <<EOF
#!/bin/sh
getent group containers >/dev/null || groupadd -r containers
if ! getent passwd containers >/dev/null; then
    useradd -r -g containers -M -s /sbin/nologin -c "User for housing the sub ID range for containers" containers
fi
usermod --add-subuids 200000-16199999 --add-subgids 200000-16199999 containers
EOF

chmod +x %{service_name}-subid.sh
install -pZm 755 %{service_name}-subid.sh %{buildroot}%{_libexecdir}/%{service_name}/%{service_name}-subid.sh

# Write a preset file to enable it by default
echo "enable %{service_name}-subid.service" > %{service_name}-subid.preset
install -Dm644 %{service_name}-subid.preset %{buildroot}%{_presetdir}/50-%{service_name}-subid.preset

%check
%if 0%{?with_check}
export GOPATH=%{buildroot}/%{gopath}:$(pwd)/Godeps/_workspace:%{gopath}
%endif

%post
%systemd_post %{service_name}
%systemd_post %{service_name}-subid
%tmpfiles_create %{_tmpfilesdir}/crio-seccomp.conf

%preun
%systemd_preun %{service_name}
%systemd_preun %{service_name}-subid

%postun
%systemd_postun_with_restart %{service_name}
%systemd_postun %{service_name}-subid

#define license tag if not already defined
%{!?_licensedir:%global license %doc}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{service_name}
%{_bindir}/%{service_name}-status
%{_bindir}/pinns
%{_mandir}/man5/%{service_name}.conf*5*
%{_mandir}/man8/%{service_name}*.8*
%dir %{_sysconfdir}/%{service_name}
%config(noreplace) %{_sysconfdir}/%{service_name}/%{service_name}.conf
%config(noreplace) %{_sysconfdir}/%{service_name}/seccomp.json
%config(noreplace) %{_sysconfdir}/cni/net.d/100-%{service_name}-bridge.conflist
%config(noreplace) %{_sysconfdir}/cni/net.d/200-loopback.conflist
%config(noreplace) %{_sysconfdir}/crictl.yaml
%{_unitdir}/%{service_name}.service
%{_unitdir}/%{service_name}-wipe.service
%{_unitdir}/%{service_name}-subid.service
%{_presetdir}/50-%{service_name}-subid.preset
%dir %{_sharedstatedir}/containers
%dir %{_sharedstatedir}/cni
%dir %{_sharedstatedir}/cni/bin
%dir %{_sysconfdir}/kubernetes
%dir %{_sysconfdir}/kubernetes/cni
%dir %{_sysconfdir}/kubernetes/cni/net.d
%dir %{_datadir}/containers
%dir %{_datadir}/containers/oci
%dir %{_datadir}/containers/oci/hooks.d
%dir /opt/cni
%dir /opt/cni/bin
%dir %{_datadir}/oci-umount
%dir %{_datadir}/oci-umount/oci-umount.d
%dir %{_libexecdir}/%{service_name}
%{_libexecdir}/%{service_name}/%{service_name}-subid.sh
%{_libexecdir}/%{service_name}/unshare.json
%{_datadir}/oci-umount/oci-umount.d/%{service_name}-umount.conf
%{_datadir}/bash-completion/completions/%{service_name}*
%{_datadir}/fish/completions/%{service_name}*.fish
%{_datadir}/zsh/site-functions/_%{service_name}*
%{_tmpfilesdir}/crio-seccomp.conf

%changelog
* Tue Jan 09 2024 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.2-7.rhaos4.14.git1cc7a64
- autobuilt 1cc7a64

* Tue Jan 09 2024 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.2-6.rhaos4.14.gita956eb5
- autobuilt a956eb5

* Tue Jan 09 2024 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.2-5.rhaos4.14.git38d8171
- autobuilt 38d8171

* Tue Dec 12 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.2-4.rhaos4.14.git15396b1
- autobuilt 15396b1

* Mon Dec 11 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.2-3.rhaos4.14.git2864b99
- autobuilt 2864b99

* Thu Nov 16 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.2-2.rhaos4.14.git9d684e2
- bump to 1.27.2
- autobuilt 9d684e2

* Wed Nov 01 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.1-13.1.rhaos4.14.git956c5f7
- autobuilt 956c5f7

* Wed Nov 01 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.1-12.1.rhaos4.14.gitfe7bb3c
- autobuilt fe7bb3c

* Thu Oct 26 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.1-11.1.rhaos4.14.git9b9c375
- autobuilt 9b9c375

* Thu Oct 26 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.1-10.1.rhaos4.14.git9a24aae
- autobuilt 9a24aae

* Wed Oct 25 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.1-9.1.rhaos4.14.git7d54551
- autobuilt 7d54551

* Thu Oct 19 2023 Siddharth Sharma <sidsharm@redhat.com> - 1.27.1-8.1.rhaos4.14.git3fecb83
Bump and rebuild with latest golang, resolves ART-7950

* Thu Sep 14 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.1-8.rhaos4.14.git3fecb83
- autobuilt 3fecb83

* Mon Sep 11 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.1-7.rhaos4.14.git57d0fe5
- autobuilt 57d0fe5

* Wed Aug 09 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.1-6.rhaos4.14.gitc2c9f36
- autobuilt c2c9f36

* Mon Aug 07 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.1-5.rhaos4.14.git25f83b3
- autobuilt 25f83b3

* Thu Jul 27 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.1-4.rhaos4.14.gitab7845e
- autobuilt ab7845e

* Tue Jul 25 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.1-3.rhaos4.14.gited2afb7
- autobuilt ed2afb7

* Wed Jul 12 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.1-2.rhaos4.14.git65a8134
- bump to 1.27.1
- autobuilt 65a8134

* Thu Jul 06 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.0-18.rhaos4.14.git3abbef7
- autobuilt 3abbef7

* Tue Jun 27 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.0-17.rhaos4.14.git07abd66
- autobuilt 07abd66

* Tue Jun 27 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.0-16.rhaos4.14.gite1c23c1
- autobuilt e1c23c1

* Wed Jun 21 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.0-15.rhaos4.14.gite4473f5
- autobuilt e4473f5

* Wed Jun 21 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.0-14.rhaos4.14.git1475b89
- autobuilt 1475b89

* Mon Jun 12 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.0-13.rhaos4.14.gitea0d970
- autobuilt ea0d970

* Fri Jun 09 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.0-12.rhaos4.14.gita48606a
- autobuilt a48606a

* Tue Jun 06 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.0-11.rhaos4.14.gitc845e7b
- autobuilt c845e7b

* Fri Jun 02 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.0-10.rhaos4.14.git519739a
- autobuilt 519739a

* Tue May 30 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.0-9.rhaos4.14.git55f1d5c
- autobuilt 55f1d5c

* Thu May 25 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.0-8.rhaos4.14.git00c6e18
- autobuilt 00c6e18

* Thu May 18 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.0-7.rhaos4.14.gitc11e24e
- autobuilt c11e24e

* Wed May 10 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.0-6.rhaos4.14.git81ac4ce
- autobuilt 81ac4ce

* Thu May 04 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.0-5.rhaos4.14.git23360b1
- autobuilt 23360b1

* Fri Apr 28 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.0-4.rhaos4.14.git19bc548
- autobuilt 19bc548

* Thu Apr 27 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.0-3.rhaos4.14.git4d2031f
- autobuilt 4d2031f

* Thu Apr 20 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.27.0-2.rhaos4.14.git90a1e14
- bump to 1.27.0
- autobuilt 90a1e14

* Thu Apr 13 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.3-3.rhaos4.14.git641290e
- autobuilt 641290e

* Mon Apr 10 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.3-2.rhaos4.14.gitafec31f
- bump to 1.26.3
- autobuilt afec31f

* Mon Apr 03 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.2-8.rhaos4.14.gita8e12c5
- autobuilt a8e12c5

* Thu Mar 30 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.2-7.rhaos4.14.gitc0557b8
- autobuilt c0557b8

* Wed Mar 29 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.2-6.rhaos4.14.git2dc35d4
- autobuilt 2dc35d4

* Mon Mar 27 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.2-5.rhaos4.14.gitc8c985b
- autobuilt c8c985b

-* Fri Mar 31 2023 Peter Hunt <pehunt@redhat.com> - 1.26.2-5.rhaos4.14.git1b022da
-- bump to 4.14

* Tue Mar 14 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.2-4.rhaos4.13.git1b022da
- autobuilt 1b022da

* Tue Mar 14 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.2-3.rhaos4.13.gitae323b1
- autobuilt ae323b1

* Wed Mar 08 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.2-2.rhaos4.13.gitb884aca
- bump to 1.26.2
- autobuilt b884aca

* Wed Mar 08 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.1-14.rhaos4.13.gitb377ead
- autobuilt b377ead

* Tue Mar 07 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.1-13.rhaos4.13.gitb4f6280
- autobuilt b4f6280

* Tue Mar 07 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.1-12.rhaos4.13.git06d125c
- autobuilt 06d125c

* Tue Feb 28 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.1-11.rhaos4.13.git0fe105f
- autobuilt 0fe105f

* Thu Feb 23 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.1-10.rhaos4.13.gitcb86088
- autobuilt cb86088

* Wed Feb 22 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.1-9.rhaos4.13.gitc18696c
- autobuilt c18696c

* Mon Feb 13 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.1-8.rhaos4.13.git3de3f95
- autobuilt 3de3f95

* Wed Feb 08 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.1-7.rhaos4.13.git5d3e55e
- autobuilt 5d3e55e

* Wed Jan 25 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.1-6.rhaos4.13.git159cc9c
- autobuilt 159cc9c

* Tue Jan 24 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.1-5.rhaos4.13.git20f3355
- autobuilt 20f3355

* Fri Jan 13 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.1-4.rhaos4.13.gita78722c
- autobuilt a78722c

* Thu Jan 12 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.1-3.rhaos4.13.git17d5fdc
- autobuilt 17d5fdc

* Tue Jan 10 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.1-2.rhaos4.13.git69945ab
- bump to 1.26.1
- autobuilt 69945ab

* Tue Jan 10 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.0-5.rhaos4.13.gita750c5c
- autobuilt a750c5c

* Tue Jan 10 2023 Peter Hunt~ <pehunt@redhat.com> - 1.26.0-4.rhaos4.13.git55a8ff7
- install seccomp profile with symlink, because rhcos clears /var/lib

* Thu Jan 05 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.0-3.rhaos4.13.git55a8ff7
- autobuilt 55a8ff7

* Wed Jan 04 2023 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.26.0-2.rhaos4.13.gitf59ba5e
- bump to 1.26.0
- autobuilt f59ba5e

* Fri Oct 07 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.1-2.rhaos4.12.gitafa0c57
- bump to 1.25.1
- autobuilt afa0c57

* Thu Oct 06 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-60.rhaos4.12.gita759fa0
- autobuilt a759fa0

* Wed Oct 05 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-59.rhaos4.12.git1460954
- autobuilt 1460954

* Wed Oct 05 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-58.rhaos4.12.gitc9b1468
- autobuilt c9b1468

* Wed Oct 05 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-57.rhaos4.12.gitd0c975f
- autobuilt d0c975f

* Mon Oct 03 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-56.rhaos4.12.git9961d62
- autobuilt 9961d62

* Thu Sep 29 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-55.rhaos4.12.git2002c49
- autobuilt 2002c49

* Thu Sep 22 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-54.rhaos4.12.git5f5e228
- autobuilt 5f5e228

* Wed Sep 21 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-53.rhaos4.12.git7629206
- autobuilt 7629206

* Wed Sep 14 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-52.rhaos4.12.gitb20aabf
- autobuilt b20aabf

* Wed Aug 31 2022 Peter Hunt~ <pehunt@redhat.com> - 1.25.0-51.rhaos4.12.git315a0cb
- drop skip_pod_runtime tag

* Mon Aug 29 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-50.rhaos4.12.git315a0cb
- autobuilt 315a0cb

* Mon Aug 29 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-49.rhaos4.12.gitf6b5837
- autobuilt f6b5837

* Mon Aug 29 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-48.rhaos4.12.gitf975faa
- autobuilt f975faa

* Fri Aug 26 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-47.rhaos4.12.git29413d8
- autobuilt 29413d8

* Fri Aug 26 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-46.rhaos4.12.giteb558b8
- autobuilt eb558b8

* Thu Aug 25 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-45.rhaos4.12.gita0ffc30
- autobuilt a0ffc30

* Thu Aug 25 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-44.rhaos4.12.git9a005e9
- autobuilt 9a005e9

* Thu Aug 25 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-43.rhaos4.12.git42b5853
- autobuilt 42b5853

* Wed Aug 24 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-42.rhaos4.12.gitaaf6efe
- autobuilt aaf6efe

* Wed Aug 24 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-41.rhaos4.12.git7ad223a
- autobuilt 7ad223a

* Wed Aug 24 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-40.rhaos4.12.git313cfd8
- autobuilt 313cfd8

* Wed Aug 24 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-39.rhaos4.12.git0817348
- autobuilt 0817348

* Tue Aug 23 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-38.rhaos4.12.gitcde21f0
- autobuilt cde21f0

* Tue Aug 23 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-37.rhaos4.12.git4e9322c
- autobuilt 4e9322c

* Tue Aug 23 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-36.rhaos4.12.gitb7cdfa2
- autobuilt b7cdfa2

* Tue Aug 23 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-35.rhaos4.12.git5f0ec82
- autobuilt 5f0ec82

* Mon Aug 22 2022 Peter Hunt~ <pehunt@redhat.com> - 1.25.0-34.rhaos4.12.gitda7b5b1
- add crun entry in runtimes table

* Tue Aug 16 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-33.rhaos4.12.gitda7b5b1
- autobuilt da7b5b1

* Wed Aug 10 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-32.rhaos4.12.gita73a2d7
- autobuilt a73a2d7

* Wed Aug 10 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-31.rhaos4.12.git0008137
- autobuilt 0008137

* Wed Aug 10 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-30.rhaos4.12.git1be8912
- autobuilt 1be8912

* Mon Aug 08 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-29.rhaos4.12.gitf585872
- autobuilt f585872

* Fri Aug 05 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-28.rhaos4.12.git822b484
- autobuilt 822b484

* Thu Aug 04 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-27.rhaos4.12.git20f639c
- autobuilt 20f639c

* Thu Aug 04 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-26.rhaos4.12.git1076ee7
- autobuilt 1076ee7

* Thu Aug 04 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-25.rhaos4.12.gitfd19918
- autobuilt fd19918

* Thu Aug 04 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-24.rhaos4.12.git57bbd3d
- autobuilt 57bbd3d

* Thu Aug 04 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-23.rhaos4.12.gitaeb88a3
- autobuilt aeb88a3

* Wed Aug 03 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-22.rhaos4.12.git0f1eaed
- autobuilt 0f1eaed

* Wed Aug 03 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-21.rhaos4.12.git9c041d9
- autobuilt 9c041d9

* Wed Aug 03 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-20.rhaos4.12.gitdcde858
- autobuilt dcde858

* Tue Aug 02 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-19.rhaos4.12.gitcfabc09
- autobuilt cfabc09

* Mon Aug 01 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-18.rhaos4.12.gita91b943
- autobuilt a91b943

* Mon Aug 01 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-17.rhaos4.12.gitbad6cae
- autobuilt bad6cae

* Sun Jul 31 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-16.rhaos4.12.gite3cef0a
- autobuilt e3cef0a

* Thu Jul 28 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-15.rhaos4.12.git6b8ba7f
- autobuilt 6b8ba7f

* Thu Jul 28 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-14.rhaos4.12.gitdabbc81
- autobuilt dabbc81

* Thu Jul 28 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-13.rhaos4.12.git2c89593
- autobuilt 2c89593

* Wed Jul 27 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-12.rhaos4.12.gitdf67c83
- autobuilt df67c83

* Tue Jul 26 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-11.rhaos4.12.git3c28cda
- autobuilt 3c28cda

* Thu Jul 21 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-10.rhaos4.12.git9afd1f7
- autobuilt 9afd1f7

* Thu Jul 21 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-9.rhaos4.12.git6280d9a
- autobuilt 6280d9a

* Thu Jul 21 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-8.rhaos4.12.git6e369c8
- autobuilt 6e369c8

* Thu Jul 21 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-7.rhaos4.12.gita2e57f2
- autobuilt a2e57f2

* Wed Jul 20 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-6.rhaos4.12.gitaaa21f2
- autobuilt aaa21f2

* Wed Jul 20 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-5.rhaos4.12.git2d64081
- autobuilt 2d64081

* Tue Jul 19 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-4.rhaos4.12.gitc9c99cf
- autobuilt c9c99cf

* Tue Jul 19 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-3.rhaos4.12.gitde48c78
- autobuilt de48c78

* Tue Jul 19 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.25.0-2.rhaos4.12.git0ec81ee
- bump to 1.25.0
- autobuilt 0ec81ee

* Fri Jun 17 2022 Peter Hunt <pehunt@redhat.com> - 1.24.1-6.rhaos4.11.gitff26732
- add unshare.json

* Thu Jun 16 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.1-5.rhaos4.11.gitff26732
- autobuilt ff26732

* Thu Jun 16 2022 Peter Hunt <pehunt@redhat.com> - 1.24.1-4.rhaos4.11.git0e22ab4
- remove patches

* Tue Jun 14 2022 Peter Hunt <pehunt@redhat.com> - 1.24.1-3.rhaos4.11.git0e22ab4
- update debugging patch

* Tue Jun 14 2022 Peter Hunt <pehunt@redhat.com> - 1.24.1-2.rhaos4.11.git0e22ab4
- add stop container debugging

* Fri Jun 03 2022 Peter Hunt <pehunt@redhat.com> - 1.24.1-1.rhaos4.11.git0e22ab4
- bump to v1.24.1

* Thu Jun 02 2022 Peter Hunt <pehunt@redhat.com> - 1.24.0-49.rhaos4.11.git0e22ab4
- add cve-2022-1822.patch

* Thu Jun 02 2022 Peter Hunt <pehunt@redhat.com> - 1.24.0-48.rhaos4.11.git0e22ab4
- drop ocicni-vendor.patch

* Tue May 31 2022 Peter Hunt <pehunt@redhat.com> - 1.24.0-47.rhaos4.11.git0e22ab4
- make containers user a system user

* Wed May 25 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-46.rhaos4.11.git0e22ab4
- autobuilt 0e22ab4

* Thu May 19 2022 Peter Hunt <pehunt@redhat.com> - 1.24.0-45.rhaos4.11.gitccef160
- patch vendor with debugging info

* Tue May 17 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-44.rhaos4.11.gitccef160
- autobuilt ccef160

* Tue May 10 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-43.rhaos4.11.git0ba47c9
- autobuilt 0ba47c9

* Mon May 09 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-42.rhaos4.11.git895030c
- autobuilt 895030c

* Mon May 09 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-41.rhaos4.11.git99bd2ae
- autobuilt 99bd2ae

* Mon May 09 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-40.rhaos4.11.gitc84b87c
- autobuilt c84b87c

* Mon May 09 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-39.rhaos4.11.gitbd44e1a
- autobuilt bd44e1a

* Fri May 06 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-38.rhaos4.11.git231af70
- autobuilt 231af70

* Fri May 06 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-37.rhaos4.11.git41ee288
- autobuilt 41ee288

* Fri May 06 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-36.rhaos4.11.gitc62a882
- autobuilt c62a882

* Thu May 05 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-35.rhaos4.11.git79f1cf0
- autobuilt 79f1cf0

* Thu May 05 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-34.rhaos4.11.git34654ec
- autobuilt 34654ec

* Thu May 05 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-33.rhaos4.11.gitd45c5d3
- autobuilt d45c5d3

* Mon May 02 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-32.rhaos4.11.gitc17baa0
- autobuilt c17baa0

* Fri Apr 29 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-31.rhaos4.11.gitfa99402
- autobuilt fa99402

* Thu Apr 28 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-30.rhaos4.11.git40cdd9c
- autobuilt 40cdd9c

* Thu Apr 28 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-29.rhaos4.11.git761c2c1
- autobuilt 761c2c1

* Thu Apr 28 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-28.rhaos4.11.git63f072d
- autobuilt 63f072d

* Wed Apr 27 2022 Peter Hunt <pehunt@redhat.com> - 1.24.0-27.rhaos4.11.gitaf4c8ed
- drop seccomp.json

* Wed Apr 27 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-26.rhaos4.11.gitaf4c8ed
- autobuilt af4c8ed

* Wed Apr 27 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-25.rhaos4.11.git6b64b6e
- autobuilt 6b64b6e

* Tue Apr 26 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-24.rhaos4.11.git2884416
- autobuilt 2884416

* Fri Apr 22 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-23.rhaos4.11.gita68a720
- autobuilt a68a720

* Fri Apr 22 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-22.rhaos4.11.git2aae963
- autobuilt 2aae963

* Thu Apr 21 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-21.rhaos4.11.git75acffa
- autobuilt 75acffa

* Thu Apr 21 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-20.rhaos4.11.git85626da
- autobuilt 85626da

* Thu Apr 21 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-19.rhaos4.11.gita9a4b7a
- autobuilt a9a4b7a

* Thu Apr 21 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-18.rhaos4.11.git9f1f420
- autobuilt 9f1f420

* Thu Apr 14 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-17.rhaos4.11.git149ccca
- autobuilt 149ccca

* Wed Apr 13 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-16.rhaos4.11.git9947b89
- autobuilt 9947b89

* Tue Apr 12 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-15.rhaos4.11.git9ed9393
- autobuilt 9ed9393

* Thu Apr 07 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-14.rhaos4.11.git4db8e81
- autobuilt 4db8e81

* Wed Apr 06 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-13.rhaos4.11.git3d25563
- autobuilt 3d25563

* Tue Apr 05 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-12.rhaos4.11.gitf544f91
- autobuilt f544f91

* Tue Apr 05 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-11.rhaos4.11.gitab06558
- autobuilt ab06558

* Thu Mar 31 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-10.rhaos4.11.git7735eb6
- autobuilt 7735eb6

* Thu Mar 31 2022 Peter Hunt <pehunt@redhat.com> - 1.24.0-9.rhaos4.11.git77718dc
- add sub?id ranges

* Sun Mar 27 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-8.rhaos4.11.git77718dc
- autobuilt 77718dc

* Sun Mar 27 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-7.rhaos4.11.git59ceb0d
- autobuilt 59ceb0d

* Fri Mar 25 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-6.rhaos4.11.git6ea8734
- autobuilt 6ea8734

* Wed Mar 23 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-5.rhaos4.11.gitd020fdb
- autobuilt d020fdb

* Tue Mar 22 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-4.rhaos4.11.gitec7b602
- autobuilt ec7b602

* Mon Mar 21 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.24.0-3.rhaos4.11.git79d546e
- autobuilt 79d546e

* Mon Mar 21 2022 Peter Hunt <pehunt@redhat.com> - 1.24.0-2.rhaos4.11.gitbbe7b1e
- revert sysctl patch

* Fri Mar 04 2022 Peter Hunt <pehunt@redhat.com> - 1.24.0-1.rhaos4.11.gitbbe7b1e
- update version

* Fri Mar 04 2022 Peter Hunt <pehunt@redhat.com> - 1.23.0-105.rhaos4.10.gitbbe7b1e
- fix sysctl patch

* Thu Mar 03 2022 Peter Hunt <pehunt@redhat.com> - 1.23.0-104.rhaos4.10.gitbbe7b1e
- add sysctl patch for CVE-2022-0811

* Thu Feb 24 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-103.rhaos4.10.gitbbe7b1e
- autobuilt bbe7b1e

* Thu Jan 13 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-102.rhaos4.10.git9c23ef3
- autobuilt 9c23ef3

* Wed Jan 12 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-101.rhaos4.10.gitdc37296
- autobuilt dc37296

* Tue Jan 11 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-100.rhaos4.10.git77d20b2
- autobuilt 77d20b2

* Mon Jan 10 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-99.rhaos4.10.gitc3131de
- autobuilt c3131de

* Fri Dec 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-98.rhaos4.10.git9b7f5ae
- autobuilt 9b7f5ae

* Thu Dec 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-97.rhaos4.10.gitcbcc270
- autobuilt cbcc270

* Thu Dec 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-96.rhaos4.10.gitff7dfeb
- autobuilt ff7dfeb

* Thu Dec 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-95.rhaos4.10.git183d7ef
- autobuilt 183d7ef

* Wed Dec 15 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-94.rhaos4.10.git8da1f67
- autobuilt 8da1f67

* Tue Dec 14 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-93.rhaos4.10.git116b6ce
- autobuilt 116b6ce

* Tue Dec 14 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-92.rhaos4.10.gitdaab4d1
- autobuilt daab4d1

* Mon Dec 13 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-91.rhaos4.10.gitfc844e4
- autobuilt fc844e4

* Mon Dec 06 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-90.rhaos4.10.gitd57d291
- autobuilt d57d291

* Fri Dec 03 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-89.rhaos4.10.git367232b
- autobuilt 367232b

* Thu Dec 02 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-88.rhaos4.10.git336a2eb
- autobuilt 336a2eb

* Mon Nov 29 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-87.rhaos4.10.git1e2f62a
- autobuilt 1e2f62a

* Mon Nov 29 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-86.rhaos4.10.git3bfface
- autobuilt 3bfface

* Mon Nov 29 2021 Peter Hunt <pehunt@redhat.com> - 1.23.0-85.rhaos4.10.git7048f24
- bump version number

* Sat Nov 27 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-31.rhaos4.10.git7048f24
- bump to 1.23.0
- autobuilt 7048f24

* Tue Nov 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-30.rhaos4.10.git7048f24
- autobuilt 7048f24

* Tue Nov 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-29.rhaos4.10.git036030d
- autobuilt 036030d

* Tue Nov 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-28.rhaos4.10.git8deefdd
- autobuilt 8deefdd

* Tue Nov 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-27.rhaos4.10.git31faba4
- autobuilt 31faba4

* Fri Nov 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-26.rhaos4.10.git2874194
- autobuilt 2874194

* Fri Nov 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-25.rhaos4.10.gitacc36e5
- autobuilt acc36e5

* Thu Nov 18 2021 Peter Hunt <pehunt@redhat.com> - 1.23.0-24.rhaos4.10.git407d866
- install crio.conf, but without storage opts

* Tue Nov 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-23.rhaos4.10.git407d866
- autobuilt 407d866

* Mon Nov 15 2021 Peter Hunt <pehunt@redhat.com> - 1.23.0-22.rhaos4.10.gite2c9990
- fix crio conf removal

* Mon Nov 15 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-21.rhaos4.10.gite2c9990
- autobuilt e2c9990

* Mon Nov 15 2021 Peter Hunt <pehunt@redhat.com> - 1.23.0-20.rhaos4.10.git10a09d7
- fix seccomp source

* Thu Nov 11 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-1.rhaos4.10.git7048f249.rhaos4.10.git10a09d7
- autobuilt 10a09d7

* Thu Nov 11 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-1.rhaos4.10.git7048f248.rhaos4.10.git518dd42
- autobuilt 518dd42

* Tue Nov 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-1.rhaos4.10.git7048f247.rhaos4.10.git529276d
- autobuilt 529276d

* Tue Nov 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-1.rhaos4.10.git7048f246.rhaos4.10.gitf9a1123
- autobuilt f9a1123

* Tue Nov 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-1.rhaos4.10.git7048f245.rhaos4.10.git143babd
- autobuilt 143babd

* Mon Nov 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-1.rhaos4.10.git7048f244.rhaos4.10.gite93843f
- autobuilt e93843f

* Mon Nov 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-1.rhaos4.10.git7048f243.rhaos4.10.git181a780
- autobuilt 181a780

* Thu Nov 04 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-1.rhaos4.10.git7048f242.rhaos4.10.git3943334
- autobuilt 3943334

* Wed Nov 03 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-1.rhaos4.10.git7048f241.rhaos4.10.gitd690832
- autobuilt d690832

* Tue Nov 02 2021 Peter Hunt <pehunt@redhat.com> - 1.23.0-1.rhaos4.10.git7048f240.rhaos4.10.gitb5002c4
- bump to b5002c42fb2fab5daed0a68576c06dd9c0116f86

* Thu Oct 28 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-9.rhaos4.10.git0fb9c0c
- autobuilt 0fb9c0c

* Wed Oct 27 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-8.rhaos4.10.git2e9a711
- autobuilt 2e9a711

* Tue Oct 26 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-7.rhaos4.10.gitb026482
- autobuilt b026482

* Tue Oct 26 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-6.rhaos4.10.gitf51497f
- autobuilt f51497f

* Mon Oct 25 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-5.rhaos4.10.gitbf8bc04
- autobuilt bf8bc04

* Mon Oct 25 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-4.rhaos4.10.gite90307f
- autobuilt e90307f

* Thu Oct 21 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-3.rhaos4.10.gitfd336b5
- autobuilt fd336b5

* Thu Oct 21 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-2.rhaos4.10.gitcf735cf
- bump to 1.23.0
- autobuilt cf735cf

* Wed Oct 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-6.rhaos4.10.git6548676
- autobuilt 6548676

* Wed Oct 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-5.rhaos4.10.gitc22219b
- autobuilt c22219b

* Wed Oct 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-4.rhaos4.10.git22986bd
- autobuilt 22986bd

* Wed Oct 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-3.rhaos4.10.git8a6b305
- autobuilt 8a6b305

* Tue Oct 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-2.rhaos4.10.git7163dbb
- bump to 1.22.0
- autobuilt 7163dbb

* Mon Oct 18 2021 Peter Hunt <pehunt@redhat.com> - 1.23.0-69.rhaos4.10.gitb393084
- bump verison number

* Fri Oct 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-68.rhaos4.10.gitb393084
- autobuilt b393084

* Thu Sep 23 2021 Peter Hunt <pehunt@redhat.com> - 1.22.0-67.rhaos4.10.git6becad2
- bump rhcos version

* Wed Aug 25 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-66.rhaos4.9.git6becad2
- autobuilt 6becad2

* Tue Aug 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-65.rhaos4.9.git5d5a754
- autobuilt 5d5a754

* Tue Aug 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-64.rhaos4.9.git3682514
- autobuilt 3682514

* Tue Aug 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-63.rhaos4.9.git1d44719
- autobuilt 1d44719

* Tue Aug 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-62.rhaos4.9.git690c533
- autobuilt 690c533

* Tue Aug 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-61.rhaos4.9.gitcf0a31c
- autobuilt cf0a31c

* Tue Aug 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-60.rhaos4.9.git10db266
- autobuilt 10db266

* Tue Aug 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-59.rhaos4.9.gite3ee92e
- autobuilt e3ee92e

* Mon Aug 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-58.rhaos4.9.git4e5a828
- autobuilt 4e5a828

* Mon Aug 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-57.rhaos4.9.git411113d
- autobuilt 411113d

* Mon Aug 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-56.rhaos4.9.git9f38eee
- autobuilt 9f38eee

* Sat Aug 21 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-55.rhaos4.9.git177ed5f
- autobuilt 177ed5f

* Sat Aug 21 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-54.rhaos4.9.git8234f90
- autobuilt 8234f90

* Fri Aug 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-53.rhaos4.9.git2d289a2
- autobuilt 2d289a2

* Fri Aug 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-52.rhaos4.9.git1520733
- autobuilt 1520733

* Fri Aug 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-51.rhaos4.9.gitf05d651
- autobuilt f05d651

* Thu Aug 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-50.rhaos4.9.gitd8af189
- autobuilt d8af189

* Thu Aug 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-49.rhaos4.9.git1536782
- autobuilt 1536782

* Thu Aug 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-48.rhaos4.9.gitabbfb13
- autobuilt abbfb13

* Thu Aug 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-47.rhaos4.9.gita6ed448
- autobuilt a6ed448

* Thu Aug 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-46.rhaos4.9.git359c7f8
- autobuilt 359c7f8

* Thu Aug 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-45.rhaos4.9.git3a523e9
- autobuilt 3a523e9

* Wed Aug 18 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-44.rhaos4.9.gitc1e95b1
- autobuilt c1e95b1

* Wed Aug 18 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-43.rhaos4.9.git56fb46e
- autobuilt 56fb46e

* Wed Aug 18 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-42.rhaos4.9.gitdf41b98
- autobuilt df41b98

* Wed Aug 18 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-41.rhaos4.9.git71ab700
- autobuilt 71ab700

* Wed Aug 18 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-40.rhaos4.9.git8bcf6f7
- autobuilt 8bcf6f7

* Tue Aug 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-39.rhaos4.9.git71ec863
- autobuilt 71ec863

* Tue Aug 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-38.rhaos4.9.git94060e3
- autobuilt 94060e3

* Tue Aug 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-37.rhaos4.9.gitfe3d631
- autobuilt fe3d631

* Tue Aug 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-36.rhaos4.9.git7cc1f62
- autobuilt 7cc1f62

* Mon Aug 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-35.rhaos4.9.gitc53e78f
- autobuilt c53e78f

* Wed Aug 11 2021 Peter Hunt <pehunt@redhat.com> - 1.22.0-34.rhaos4.9.git78f06f2
- use conmon from path

* Tue Aug 10 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-33.rhaos4.9.git78f06f2
- autobuilt 78f06f2

* Mon Aug 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-32.rhaos4.9.gita07f02f
- autobuilt a07f02f

* Mon Aug 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-31.rhaos4.9.giteb3cca9
- autobuilt eb3cca9

* Mon Aug 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-30.rhaos4.9.git779df95
- autobuilt 779df95

* Sun Aug 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-29.rhaos4.9.git6092081
- autobuilt 6092081

* Fri Aug 06 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-28.rhaos4.9.git126b893
- autobuilt 126b893

* Thu Aug 05 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-27.rhaos4.9.git2c92506
- autobuilt 2c92506

* Thu Aug 05 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-26.rhaos4.9.git226e658
- autobuilt 226e658

* Wed Aug 04 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-25.rhaos4.9.gitcc72388
- autobuilt cc72388

* Wed Aug 04 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-24.rhaos4.9.git8d4df4e
- autobuilt 8d4df4e

* Tue Aug 03 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-23.rhaos4.9.gita414fed
- autobuilt a414fed

* Mon Aug 02 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-22.rhaos4.9.git79a25c4
- autobuilt 79a25c4

* Mon Aug 02 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-21.rhaos4.9.gitee8e721
- autobuilt ee8e721

* Fri Jul 30 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-20.rhaos4.9.git1b8b9e4
- autobuilt 1b8b9e4

* Thu Jul 29 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb9.rhaos4.9.git6ac8cee
- autobuilt 6ac8cee

* Wed Jul 28 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb8.rhaos4.9.git13e698f
- autobuilt 13e698f

* Wed Jul 28 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb7.rhaos4.9.gitb6d6cde
- autobuilt b6d6cde

* Tue Jul 27 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb6.rhaos4.9.git5ab85f5
- autobuilt 5ab85f5

* Mon Jul 26 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb5.rhaos4.9.gita212a95
- autobuilt a212a95

* Mon Jul 26 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb4.rhaos4.9.git4fa3dd3
- autobuilt 4fa3dd3

* Mon Jul 26 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb3.rhaos4.9.git49a8247
- autobuilt 49a8247

* Fri Jul 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb2.rhaos4.9.git0fc6d47
- autobuilt 0fc6d47

* Fri Jul 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb1.rhaos4.9.git0f8266d
- autobuilt 0f8266d

* Wed Jul 21 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb0.rhaos4.9.gite06cce2
- autobuilt e06cce2

* Tue Jul 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-9.rhaos4.9.gitaf2035b
- autobuilt af2035b

* Mon Jul 19 2021 Peter Hunt <pehunt@redhat.com> - 1.22.0-8.rhaos4.9.git1cf63c7
- sunset support for custom rpm crio.service file

* Mon Jul 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-7.rhaos4.9.git1cf63c7
- autobuilt 1cf63c7

* Sat Jul 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-6.rhaos4.9.git635b2d9
- autobuilt 635b2d9

* Sat Jul 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-5.rhaos4.9.gite00180d
- autobuilt e00180d

* Fri Jul 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-4.rhaos4.9.gitc969a38
- autobuilt c969a38

* Fri Jul 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-3.rhaos4.9.gitcd1c5a0
- autobuilt cd1c5a0

* Fri Jul 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-2.rhaos4.9.git1309dd2
- bump to 1.22.0
- autobuilt 1309dd2

* Fri Jul 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com>
- bump to 1.15.1
- autobuilt 

* Thu Jul 15 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb.rhaos4.9.git1309dd26.rhaos4.9.git4d14fd6
- autobuilt 4d14fd6

* Thu Jul 15 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb.rhaos4.9.git1309dd25.rhaos4.9.gitde5e0fe
- autobuilt de5e0fe

* Wed Jul 14 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb.rhaos4.9.git1309dd24.rhaos4.9.gitf2dcf32
- autobuilt f2dcf32

* Wed Jul 14 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb.rhaos4.9.git1309dd23.rhaos4.9.gitacd0f73
- autobuilt acd0f73

* Wed Jul 14 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb.rhaos4.9.git1309dd22.rhaos4.9.gitb123b0c
- autobuilt b123b0c

* Wed Jul 14 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb.rhaos4.9.git1309dd21.rhaos4.9.gitab3a2f4
- autobuilt ab3a2f4

* Tue Jul 13 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb.rhaos4.9.git1309dd20.rhaos4.9.git196e779
- autobuilt 196e779

* Thu Jul 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-9.rhaos4.9.giteffa584
- autobuilt effa584

* Thu Jul 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-8.rhaos4.9.git472b3ae
- autobuilt 472b3ae

* Thu Jul 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-7.rhaos4.9.gitfeb7a4c
- autobuilt feb7a4c

* Wed Jul 07 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-6.rhaos4.9.git3e5a1e4
- autobuilt 3e5a1e4

* Mon Jul 05 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-5.rhaos4.9.gitc8b82d6
- autobuilt c8b82d6

* Sat Jul 03 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-4.rhaos4.9.gitd41627b
- autobuilt d41627b

* Thu Jul 01 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-3.rhaos4.9.git0aa5724
- autobuilt 0aa5724

* Thu Jul 01 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-2.rhaos4.9.git2b8e727
- bump to 1.22.0
- autobuilt 2b8e727

* Wed Jun 30 2021 Peter Hunt <pehunt@redhat.com> - 1.21.0-5.rhaos4.9.git741bd7c
- rebuild for golang fips fix

* Wed Jun 30 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-4.rhaos4.9.git741bd7c
- autobuilt 741bd7c

* Wed Jun 30 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-3.rhaos4.9.git6664604
- autobuilt 6664604

* Tue Jun 29 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-2.rhaos4.9.git9dd6f42
- bump to 1.21.0
- autobuilt 9dd6f42

* Tue Jun 29 2021 Peter Hunt <pehunt@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb.rhaos4.9.git1309dd2.rhaos4.9.git2b8e727.rhaos4.9.gitcd7f051
- Initial build of 1.22


